@@ -2,7 +2,8 @@
 
 import torch
 from torch import nn, Tensor
-
+from torch import isnan,tensor
+from torch import sum as summer
 from torchnorms.tnorms.base import BaseTNorm
 
 from typing import Optional
@@ -39,3 +40,8 @@ class AczelAlsinaTNorm(BaseTNorm):
         p_2 = torch.pow(torch.abs(torch.log(b)), self.p)
         res = torch.exp(-torch.pow(p_1 + p_2, 1.0 / self.p))
         return res
+
+    def adjust_nan_param(self):
+        for param in self.parameters():
+            if summer(isnan(param)):
+                param.data = tensor(0.1, device = param.device)
